Structs
- Typescript
Converter - Provides ability to convert syn (https://crates.io/crates/syn) parser types to typescript types with ease
- Typescript
Type
Enums
Functions
- convert_
all_ types_ in_ path - Function for generating typescript bindings for every rust type in every file in a given rapid project
- convert_
primitive - Function for converting basic rust primitive types to typescript types and interfaces
- get_
rust_ typename - Function for getting the type name as a string from a rust struct