Structs
Enums
Functions
- create_
typescript_ types - generate_
handler_ types - Function for generating typescript types from a rapid routes directory
- generate_
routes - Function for generating a route handler object for use on the client It will output something similar to the following: const routes = { index: ‘/’ }