Module convert

Module convert 

Structs

TypescriptConverter
Provides ability to convert syn (https://crates.io/crates/syn) parser types to typescript types with ease
TypescriptType

Enums

ConversionType

Functions

convert_all_types_in_path
Function for generating typescript bindings for every rust type in every file in a given rapid project
convert_primitive
Function for converting basic rust primitive types to typescript types and interfaces
get_rust_typename
Function for getting the type name as a string from a rust struct