pub struct TypescriptConverter {
pub is_interface: bool,
pub store: String,
pub should_export: bool,
pub indentation: u32,
pub file: File,
pub converted_types: Vec<String>,
}Expand description
Provides ability to convert syn (https://crates.io/crates/syn) parser types to typescript types with ease
Fields
is_interface: boolstore: Stringshould_export: boolindentation: u32file: Fileconverted_types: Vec<String>Implementations
Sourceimpl TypescriptConverter
impl TypescriptConverter
pub fn new( is_interface: bool, initial_store_value: String, should_export: bool, indentation: u32, file: File, ) -> Self
Sourcepub fn convert_struct(&mut self, rust_struct: ItemStruct)
pub fn convert_struct(&mut self, rust_struct: ItemStruct)
Function that converts a syn struct to a typescript interface and pushes it to the store field
Sourcepub fn convert_primitive(&mut self, primitive: Type) -> TypescriptType
pub fn convert_primitive(&mut self, primitive: Type) -> TypescriptType
Converts rust primitives to typescript types
pub fn convert_const()
pub fn convert_enum()
pub fn convert_function()
Sourcepub fn convert_type_alias(&mut self, rust_type_alias: ItemType)
pub fn convert_type_alias(&mut self, rust_type_alias: ItemType)
Converts rust type aliases to typescript types or interfaces
pub fn generate(&mut self, types: Option<&str>)